summaryrefslogtreecommitdiff
path: root/gcc/tracer.c
diff options
context:
space:
mode:
authorRichard Sandiford <rsandifo@redhat.com>2004-07-26 14:34:19 +0000
committerRichard Sandiford <rsandifo@gcc.gnu.org>2004-07-26 14:34:19 +0000
commit35b6b437aa03e95ab2eb6fa5acaf25e07a9b1433 (patch)
tree4287b222452a3f92e4472b74970cdf9826728da2 /gcc/tracer.c
parentfa0a2ae5e38f358c9c1b1480a6c5b291ea5201bd (diff)
downloadgcc-35b6b437aa03e95ab2eb6fa5acaf25e07a9b1433.tar.gz
re PR rtl-optimization/16643 (verify_local_live_at_start ICE after crossjumping & cfgcleanup)
PR rtl-optimization/16643 * cfglayout.h (cfg_layout_initialize): Add a flags parameter. * cfglayout.c (cfg_layout_initialize): Pass it to cleanup_cfg. * basic-block.h (reorder_basic_blocks): Add a flags parameter. * cfglayout.c (reorder_basic_blocks): Pass it to cfg_layout_initialize. (partition_hot_cold_basic_blocks): Pass 0 to cfg_layout_initialize. * function.c (thread_prologue_and_epilogue_insns): Likewise. * rtl.h (tracer): Add a flags parameter. * tracer.c (tracer): Pass it to cfg_layout_initialise. * passes.c (rest_of_handle_stack_regs): Pass 0 to reorder_basic_blocks. (rest_of_handle_reorder_blocks): Update calls to tracer and reorder_basic_blocks, passing CLEANUP_UPDATE_LIFE if appropriate. (rest_of_handle_tracer): Pass 0 to tracer. (rest_of_handle_loop2): Pass 0 to cfg_layout_initialize. From-SVN: r85191
Diffstat (limited to 'gcc/tracer.c')
-rw-r--r--gcc/tracer.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/gcc/tracer.c b/gcc/tracer.c
index 9635737ff53..dd263c4fdfd 100644
--- a/gcc/tracer.c
+++ b/gcc/tracer.c
@@ -354,17 +354,18 @@ layout_superblocks (void)
}
}
-/* Main entry point to this file. */
+/* Main entry point to this file. FLAGS is the set of flags to pass
+ to cfg_layout_initialize(). */
void
-tracer (void)
+tracer (unsigned int flags)
{
if (n_basic_blocks <= 1)
return;
timevar_push (TV_TRACER);
- cfg_layout_initialize ();
+ cfg_layout_initialize (flags);
mark_dfs_back_edges ();
if (dump_file)
dump_flow_info (dump_file);